@@ -1,7 +1,7 @@
 #' Split the data into training and test datasets
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.split_data}{\code{IAI.split_data}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.split_data}{\code{IAI.split_data}}
 #'
 #' @param task The type of problem.
 #' @param X The features of the data.
@@ -39,62 +39,101 @@ split_data <- function(task, X, ...) {
 #' Fits a model to the training data
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.fit!}{\code{IAI.fit!}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit\%21-Tuple\%7BLearner\%7D}{\code{IAI.fit!}}
 #'
-#' @param lnr The learner or grid to fit.
+#' @param obj The learner to fit.
 #' @param X The features of the data.
 #' @param ... Other parameters, including zero or more target vectors as
 #'            required by the problem type. Refer to the Julia documentation for
 #'            available parameters.
 #'
-#' @example examples/fit.R
+#' @example examples/fit.learner.R
 #'
 #' @export
-fit <- function(lnr, X, ...) {
-  jl_func("IAI.fit_convert", lnr, X, ...)
-  lnr
+fit.learner <- function(obj, X, ...) {
+  fit_common(obj, X, ...)
+}
+#' Fits a \code{\link{grid_search}} to the training data
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit\%21-Tuple\%7BGridSearch\%7D}{\code{IAI.fit!}}
+#'
+#' @param obj The grid search to fit.
+#' @param X The features of the data.
+#' @param ... Other parameters, including zero or more target vectors as
+#'            required by the problem type. Refer to the Julia documentation for
+#'            available parameters.
+#'
+#' @example examples/fit.grid_search.R
+#'
+#' @export
+fit.grid_search <- function(obj, X, ...) {
+  fit_common(obj, X, ...)
+}
+#' Fits an imputation learner to the training data.
+#'
+#' Additional keyword arguments are available for fitting imputation learners -
+#' please refer to the Julia documentation.
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.fit\%21-Tuple\%7BLearner\%7BIAIBase.ImputationTask\%7D\%7D}{\code{IAI.fit!}}
+#'
+#' @param obj The learner or grid to fit.
+#' @param X The features of the data.
+#' @param ... Refer to the Julia documentation for available parameters.
+#'
+#' @examples \dontrun{iai::fit(lnr, X)}
+#'
+#' @export
+fit.imputation_learner <- function(obj, X, ...) {
+  fit_common(obj, X, ...)
 }
 
 
-#' Return the predictions made by the model for each point in the features
+#' Return the predictions made by a supervised learner for each point in the
+#' features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict}{\code{IAI.predict}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict-Tuple\%7BSupervisedLearner\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict}}
 #'
-#' @param lnr The learner or grid to use for prediction.
+#' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
 #' @param ... Refer to the Julia documentation for available parameters.
 #'
 #' @examples \dontrun{iai::predict(lnr, X)}
 #'
 #' @export
-predict <- function(lnr, X, ...) {
-  out <- jl_func("IAI.predict_convert", lnr, X, ...)
-  if (typeof(out) == "list" && length(out) == 2) {
-    names(out) <- c("treatments", "outcomes")
-  }
-  out
+predict.supervised_learner <- function(obj, X, ...) {
+  predict_common(obj, X, ...)
 }
-
-
-#' Generic function for calculating scores
+#' Return the predictions made by a survival learner for each point in the
+#' features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.score}{\code{IAI.score}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict-Tuple\%7BLearner\%7BIAIBase.SurvivalTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict}}
 #'
-#' @param obj The object controlling which method is used
-#' @param ... Arguments depending on the specific method used
+#' @param obj The learner or grid to use for prediction.
+#' @param X The features of the data.
+#' @param t The time for which to predict survival probability, defaulting to
+#'          returning the entire survival curve if not supplied
+#' @param ... Additional arguments (unused)
+#'
+#' @examples \dontrun{iai::predict(lnr, X, t = 10)}
 #'
 #' @export
-score <- function(obj, ...) {
-  UseMethod("score", obj)
+predict.survival_learner <- function(obj, X, t = NULL, ...) {
+  if (is.null(t) && iai_version_less_than("2.1.0")) {
+    predict_common(obj, X, ...)
+  } else {
+    predict_common(obj, X, t = t, ...)
+  }
 }
 
 
 #' Calculate the score for a model on the given data
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.score}{\code{IAI.score}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.score-Tuple\%7BSupervisedLearner\%7D}{\code{IAI.score}}
 #'
 #' @param obj The learner or grid to evaluate.
 #' @param X The features of the data.
@@ -102,24 +141,22 @@ score <- function(obj, ...) {
 #'            required by the problem type. Refer to the Julia documentation for
 #'            available parameters.
 #'
-#' @examples \dontrun{iai::score(obj, X, y)}
+#' @examples \dontrun{iai::score(lnr, X, y)}
 #'
 #' @export
-score.learner <- function(obj, X, ...) {
-  jl_func("IAI.score_convert", obj, X, ...)
+score.supervised_learner <- function(obj, X, ...) {
+  score_common(obj, X, ...)
 }
-
-
 #' Calculate the score for a set of predictions on the given data
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.score}{\code{IAI.score}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.score-Tuple\%7BUnion\%7BAbstractString\%2C\%20Symbol\%7D\%2C\%20Vararg\%7BAny\%7D\%7D}{\code{IAI.score}}
 #'
 #' @param obj The type of problem.
 #' @param predictions The predictions to evaluate.
 #' @param truths The true target values for these observations.
-#' @param ... Other parameters, including the criterion. Refer to the Julia documentation for
-#'            available parameters.
+#' @param ... Other parameters, including the criterion. Refer to the Julia
+#'            documentation for available parameters.
 #'
 #' @examples \dontrun{iai::score("regression", y_pred, y_true, criterion="mse")}
 #'
@@ -128,33 +165,33 @@ score.learner <- function(obj, X, ...) {
 #'
 #' @export
 score.default <- function(obj, predictions, truths, ...) {
-  requires_iai_version("2.1.0", "score")
-  jl_func("IAI.score_convert", obj, predictions, truths, ...)
+  requires_iai_version("2.1.0", "score", "with predictions and true labels")
+  score_common(obj, predictions, truths, ...)
 }
 
 
-#' Generate a ranking of the variables in the learner according to their
+#' Generate a ranking of the variables in a learner according to their
 #' importance during training. The results are normalized so that they sum to
 #' one.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.variable_importance}{\code{IAI.variable_importance}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.variable_importance-Tuple\%7BLearner\%7D}{\code{IAI.variable_importance}}
 #'
-#' @param lnr The learner to query.
+#' @param obj The learner to query.
 #' @param ... Refer to the Julia documentation for available parameters.
 #'
 #' @examples \dontrun{iai::variable_importance(lnr, ...)}
 #'
 #' @export
-variable_importance <- function(lnr, ...) {
-  jl_func("IAI.variable_importance_convert", lnr, ...)
+variable_importance.learner <- function(obj, ...) {
+  variable_importance_common(obj, ...)
 }
 
 
 #' Return the names of the features used by the learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_features_used}{\code{IAI.get_features_used}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_features_used}{\code{IAI.get_features_used}}
 #'
 #' @param lnr The learner to query.
 #'
@@ -173,7 +210,7 @@ get_features_used <- function(lnr) {
 #' Output a learner or grid in JSON format
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.write_json}{\code{IAI.write_json}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.write_json}{\code{IAI.write_json}}
 #'
 #' @param filename Where to save the output.
 #' @param obj The learner or grid to output.
@@ -190,7 +227,7 @@ write_json <- function(filename, obj, ...) {
 #' Read in a learner or grid saved in JSON format
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.read_json}{\code{IAI.read_json}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.read_json}{\code{IAI.read_json}}
 #'
 #' @param filename The location of the JSON file.
 #'
@@ -202,10 +239,35 @@ read_json <- function(filename) {
 }
 
 
+#' Resume training from a checkpoint file
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.resume_from_checkpoint}{\code{IAI.resume_from_checkpoint}}
+#'
+#' @param checkpoint_file The location of the checkpoint file.
+#'
+#' @examples \dontrun{obj <- iai::resume_from_checkpoint("checkpoint.json")}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 3.1 or higher.
+#'
+#' @export
+resume_from_checkpoint <- function(checkpoint_file) {
+  requires_iai_version("3.1.0", "resume_from_checkpoint")
+  out <- jl_func("IAI.resume_from_checkpoint_convert", checkpoint_file)
+  if (typeof(out) == "list" && length(out) == 2) {
+    list(learner = set_obj_class(out[[1]]),
+         results = process_fit_predict(out[[2]]))
+  } else {
+    set_obj_class(out)
+  }
+}
+
+
 #' Return the value of all parameters on a learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_params}{\code{IAI.get_params}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_params}{\code{IAI.get_params}}
 #'
 #' @param lnr The learner to query.
 #'
@@ -220,7 +282,7 @@ get_params <- function(lnr) {
 #' Set all supplied parameters on a learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.set_params!}{\code{IAI.set_params!}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.set_params!}{\code{IAI.set_params!}}
 #'
 #' @param lnr The learner to modify.
 #' @param ... The parameters to set on the learner.
@@ -237,7 +299,7 @@ set_params <- function(lnr, ...) {
 #' Return an unfitted copy of a learner with the same parameters
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.clone}{\code{IAI.clone}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.clone}{\code{IAI.clone}}
 #'
 #' @param lnr The learner to copy.
 #'
@@ -249,30 +311,45 @@ clone <- function(lnr) {
 }
 
 
-#' Show interactive visualization of an object (such as a learner or curve) in
-#' the default browser
+#' Show interactive visualization of an object in the default browser
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.show_in_browser}{\code{IAI.show_in_browser}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.show_in_browser-Tuple\%7BAbstractVisualization\%7D}{\code{IAI.show_in_browser}}
 #'
 #' @param obj The object to visualize.
 #' @param ... Refer to the Julia documentation for available parameters.
 #'
 #' @examples \dontrun{iai::show_in_browser(lnr)}
 #'
+#' @export
+show_in_browser.abstract_visualization <- function(obj, ...) {
+  show_in_browser_common(obj, ...) # nocov
+}
+#' Show interactive visualization of a \code{\link{roc_curve}} in the default
+#' browser
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.show_in_browser-Tuple\%7BROCCurve\%7D}{\code{IAI.show_in_browser}}
+#'
+#' @param obj The curve to visualize.
+#' @param ... Refer to the Julia documentation for available parameters.
+#'
+#' @examples \dontrun{iai::show_in_browser(curve)}
+#'
 #' @section IAI Compatibility:
-#' Showing a grid search requires IAI version 2.0 or higher.
+#' Requires IAI version 1.1 or higher.
 #'
 #' @export
-show_in_browser <- function(obj, ...) {
-  jl_func("IAI.show_in_browser_convert", obj, ...) # nocov
+show_in_browser.roc_curve <- function(obj, ...) {
+  requires_iai_version("1.1.0", "show_in_browser", "with `roc_curve`")
+  show_in_browser_common(obj, ...) # nocov
 }
 
 
 #' Sets a global rich output parameter
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.set_rich_output_param!}{\code{IAI.set_rich_output_param!}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.set_rich_output_param!}{\code{IAI.set_rich_output_param!}}
 #'
 #' @param key The parameter to set.
 #' @param value The value to set
@@ -288,7 +365,7 @@ set_rich_output_param <- function(key, value) {
 #' Return the current global rich output parameter settings
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_rich_output_params}{\code{IAI.get_rich_output_params}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_rich_output_params}{\code{IAI.get_rich_output_params}}
 #'
 #' @examples \dontrun{iai::get_rich_output_params()}
 #'
@@ -301,7 +378,7 @@ get_rich_output_params <- function() {
 #' Delete a global rich output parameter
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.delete_rich_output_param!}{\code{IAI.delete_rich_output_param!}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.delete_rich_output_param!}{\code{IAI.delete_rich_output_param!}}
 #'
 #' @param key The parameter to delete.
 #'
@@ -316,7 +393,7 @@ delete_rich_output_param <- function(key) {
 #' Controls grid search over parameter combinations
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.GridSearch}{\code{IAI.GridSearch}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.GridSearch}{\code{IAI.GridSearch}}
 #'
 #' @param lnr The learner to use when validating.
 #' @param ... The parameters to validate over.
@@ -332,7 +409,7 @@ grid_search <- function(lnr, ...) {
 #' Fits a grid search to the training data with cross-validation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.fit_cv!}{\code{IAI.fit_cv!}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit_cv\%21-Tuple\%7BGridSearch\%7D}{\code{IAI.fit_cv!}}
 #'
 #' @param grid The grid to fit.
 #' @param X The features of the data.
@@ -352,7 +429,7 @@ fit_cv <- function(grid, X, ...) {
 #' Return the fitted learner using the best parameter combination from a grid
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_learner}{\code{IAI.get_learner}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_learner}{\code{IAI.get_learner}}
 #'
 #' @param grid The grid to query.
 #'
@@ -367,7 +444,7 @@ get_learner <- function(grid) {
 #' Return the best parameter combination from a grid
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_best_params}{\code{IAI.get_best_params}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_best_params}{\code{IAI.get_best_params}}
 #'
 #' @param grid The grid search to query.
 #'
@@ -399,7 +476,7 @@ get_grid_results <- function(grid) {
 #' Return a summary of the results from the grid search
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_grid_result_summary}{\code{IAI.get_grid_result_summary}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_grid_result_summary}{\code{IAI.get_grid_result_summary}}
 #'
 #' @param grid The grid search to query.
 #'
@@ -418,7 +495,7 @@ get_grid_result_summary <- function(grid) {
 #' Return a vector of lists detailing the results of the grid search
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_grid_result_details}{\code{IAI.get_grid_result_details}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_grid_result_details}{\code{IAI.get_grid_result_details}}
 #'
 #' @param grid The grid search to query.
 #'
@@ -444,59 +521,45 @@ get_grid_result_details <- function(grid) {
 }
 
 
-#' Return the probabilities of class membership predicted by a model for each
-#' point in the features
+#' Return the probabilities of class membership predicted by a classification
+#' learner for each point in the features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_proba}{\code{IAI.predict_proba}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_proba-Tuple\%7BLearner\%7BIAIBase.ClassificationTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_proba}}
 #'
-#' @param lnr The learner or grid to use for prediction.
+#' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
+#' @param ... Additional arguments (unused)
 #'
 #' @examples \dontrun{iai::predict_proba(lnr, X)}
 #'
 #' @export
-predict_proba <- function(lnr, X) {
-  jl_func("IAI.predict_proba_convert", lnr, X)
+predict_proba.classification_learner <- function(obj, X, ...) {
+  predict_proba_common(obj, X, ...)
 }
 
 
-#' Generic function for constructing an ROC curve
+#' Construct an ROC curve using a trained classification learner on the given
+#' data
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.ROCCurve}{\code{IAI.ROCCurve}}
-#'
-#' @param obj The object controlling which method is used
-#' @param ... Arguments depending on the specific method used
-#'
-#' @export
-roc_curve <- function(obj, ...) {
-  UseMethod("roc_curve", obj)
-}
-
-
-#' Construct an ROC curve using a trained model on the given data
-#'
-#' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.ROCCurve}{\code{IAI.ROCCurve}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.ROCCurve-Tuple\%7BLearner\%7BIAIBase.ClassificationTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%2C\%20AbstractVector\%7D}{\code{IAI.ROCCurve}}
 #'
 #' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
 #' @param y The labels of the data.
-#' @param ... Additional arguments (unused)
+#' @param ... Refer to the Julia documentation for available parameters.
 #'
 #' @examples \dontrun{iai::roc_curve(lnr, X, y)}
 #'
 #' @export
-roc_curve.learner <- function(obj, X, y, ...) {
-  set_obj_class(jl_func("IAI.ROCCurve_convert", obj, X, y, ...))
+roc_curve.classification_learner <- function(obj, X, y, ...) {
+  roc_curve_common(obj, X, y, ...)
 }
-
-
 #' Construct an ROC curve from predicted probabilities and true labels
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.ROCCurve}{\code{IAI.ROCCurve}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.ROCCurve-Tuple\%7BAbstractVector\%7B\%3C\%3AReal\%7D\%2C\%20AbstractVector\%7D}{\code{IAI.ROCCurve}}
 #'
 #' @param obj The predicted probabilities for each point in the data.
 #' @param y The true labels of the data.
@@ -514,11 +577,10 @@ roc_curve.default <- function(
     y,
     positive_label = stop("`positive_label` is required"),
     ...
-  ) {
+) {
   requires_iai_version("2.0.0", "roc_curve",
                        "with probabilities and true labels")
-  set_obj_class(jl_func("IAI.ROCCurve_convert", obj, y,
-                        positive_label = positive_label))
+  roc_curve_common(obj, y, positive_label = positive_label)
 }
 
 
@@ -572,8 +634,10 @@ plot.roc_curve <- function(x, ...) {
 }
 
 
-#' Extract the underlying data from an ROC curve (as returned by
-#' \href{https://docs.interpretable.ai/v3.0.0/IAI-R/reference/#iai::roc_curve}{\code{roc_curve}})
+#' Extract the underlying data from an ROC curve
+#'
+#' ROC curves are returned by \code{roc_curve}, e.g.
+#' \code{\link{roc_curve.classification_learner}}
 #'
 #' The data is returned as a list with two keys: \code{auc} giving the
 #' area-under-the-curve, and \code{coords} containing a vector of lists
@@ -582,7 +646,7 @@ plot.roc_curve <- function(x, ...) {
 #' (the threshold).
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_roc_curve_data}{\code{IAI.get_roc_curve_data}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_roc_curve_data}{\code{IAI.get_roc_curve_data}}
 #'
 #' @param curve The curve to query.
 #'
@@ -599,16 +663,16 @@ get_roc_curve_data <- function(curve) {
 
 
 #' Extract the underlying data from a survival curve (as returned by
-#' \href{https://docs.interpretable.ai/v3.0.0/IAI-R/reference/#iai::predict}{\code{predict}}
+#' \code{\link{predict.survival_learner}}
 #' or
-#' \href{https://docs.interpretable.ai/v3.0.0/IAI-R/reference/#iai::get_survival_curve}{\code{get_survival_curve}})
+#' \code{\link{get_survival_curve}})
 #'
 #' The data is returned as a list with two keys: \code{times} containing the
 #' time for each breakpoint on the curve, and \code{coefs} containing the
 #' probability for each breakpoint on the curve.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_survival_curve_data}{\code{IAI.get_survival_curve_data}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_survival_curve_data}{\code{IAI.get_survival_curve_data}}
 #'
 #' @param curve The curve to query.
 #'
@@ -620,18 +684,18 @@ get_survival_curve_data <- function(curve) {
 }
 
 
-#' Return the fitted hazard coefficient estimate made by a model for each
-#' point in the features.
+#' Return the fitted hazard coefficient estimate made by a survival learner for
+#' each point in the features.
 #'
 #' A higher hazard coefficient estimate corresponds to a smaller predicted
 #' survival time.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_hazard}{\code{IAI.predict_hazard}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_hazard-Tuple\%7BLearner\%7BIAIBase.SurvivalTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_hazard}}
 #'
-#' @param lnr The learner or grid to use for prediction.
+#' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
-#' @param ... Refer to the Julia documentation for available parameters.
+#' @param ... Additional arguments (unused)
 #'
 #' @examples \dontrun{iai::predict_hazard(lnr, X)}
 #'
@@ -639,21 +703,21 @@ get_survival_curve_data <- function(curve) {
 #' Requires IAI version 1.2 or higher.
 #'
 #' @export
-predict_hazard <- function(lnr, X, ...) {
-  requires_iai_version("1.2.0", "predict_hazard")
-  jl_func("IAI.predict_hazard_convert", lnr, X, ...)
+predict_hazard.survival_learner <- function(obj, X, ...) {
+  requires_iai_version("1.2.0", "predict_hazard", "with `survival_learner`")
+  predict_hazard_common(obj, X, ...)
 }
 
 
-#' Return the expected survival time estimate made by a model for each
-#' point in the features.
+#' Return the expected survival time estimate made by a survival learner for
+#' each point in the features.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_expected_survival_time}{\code{IAI.predict_expected_survival_time}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_expected_survival_time-Tuple\%7BLearner\%7BIAIBase.SurvivalTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_expected_survival_time}}
 #'
-#' @param lnr The learner or grid to use for prediction.
+#' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
-#' @param ... Refer to the Julia documentation for available parameters.
+#' @param ... Additional arguments (unused)
 #'
 #' @examples \dontrun{iai::predict_expected_survival_time(lnr, X)}
 #'
@@ -661,31 +725,72 @@ predict_hazard <- function(lnr, X, ...) {
 #' Requires IAI version 2.0 or higher.
 #'
 #' @export
-predict_expected_survival_time <- function(lnr, X, ...) {
-  requires_iai_version("2.0.0", "predict_expected_survival_time")
-  jl_func("IAI.predict_expected_survival_time_convert", lnr, X, ...)
+predict_expected_survival_time.survival_learner <- function(obj, X, ...) {
+  requires_iai_version("2.0.0", "predict_expected_survival_time",
+                       "with `survival_learner`")
+  predict_expected_survival_time_common(obj, X, ...)
+}
+#' Return the expected survival time estimate made by a survival curve
+#' (as returned by
+#' \code{\link{predict.survival_learner}}
+#' or
+#' \code{\link{get_survival_curve}})
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_expected_survival_time-Tuple\%7BSurvivalCurve\%7D}{\code{IAI.predict_expected_survival_time}}
+#'
+#' @param obj The survival curve to use for prediction.
+#' @param ... Additional arguments (unused)
+#'
+#' @examples \dontrun{iai::predict_expected_survival_time(curve)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 2.2 or higher.
+#'
+#' @export
+predict_expected_survival_time.survival_curve <- function(obj, ...) {
+  requires_iai_version("2.2.0", "predict_expected_survival_time",
+                       "with `survival_curve`")
+  predict_expected_survival_time_common(obj, ...)
 }
 
 
-#' Return the predicted outcome for each treatment made by a model for each
-#' point in the features
+#' Return the predicted outcome for each treatment made by a prescription
+#' learner for each point in the features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAIBase-API-Reference-1}{\code{IAI.predict_outcomes}}
-#' (for prescription or policy learners as appropriate)
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_outcomes-Tuple\%7BPrescriptionLearner\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_outcomes}}
 #'
-#' @param lnr The learner or grid to use for prediction.
+#' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
-#' @param ... For policy learners only, the reward matrix.
+#' @param ... Additional arguments (unused)
 #'
-#' @examples \dontrun{iai::predict_outcomes(lnr, X, ...)}
-#'
-#' @section IAI Compatibility:
-#' Requires IAI version 2.0 or higher for policy learners.
+#' @examples \dontrun{iai::predict_outcomes(lnr, X)}
 #'
 #' @export
-predict_outcomes <- function(lnr, X, ...) {
-  jl_func("IAI.predict_outcomes_convert", lnr, X, ...)
+predict_outcomes.prescription_learner <- function(obj, X, ...) {
+  predict_outcomes_common(obj, X, ...)
+}
+#' Return the predicted outcome for each treatment made by a policy
+#' learner for each point in the features
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_outcomes-Tuple\%7BPolicyLearner\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_outcomes}}
+#'
+#' @param obj The learner or grid to use for prediction.
+#' @param X The features of the data.
+#' @param rewards The estimated reward matrix for the data.
+#' @param ... Additional arguments (unused)
+#'
+#' @examples \dontrun{iai::predict_outcomes(lnr, X, rewards)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 2.0 or higher
+#'
+#' @export
+predict_outcomes.policy_learner <- function(obj, X, rewards, ...) {
+  requires_iai_version("2.0.0", "predict_outcomes", "with `policy_learner`")
+  predict_outcomes_common(obj, X, rewards, ...)
 }
 
 
@@ -693,7 +798,7 @@ predict_outcomes <- function(lnr, X, ...) {
 #' features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_treatment_rank}{\code{IAI.predict_treatment_rank}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_treatment_rank}{\code{IAI.predict_treatment_rank}}
 #'
 #' @param lnr The learner or grid to use for prediction.
 #' @param X The features of the data.
@@ -714,7 +819,7 @@ predict_treatment_rank <- function(lnr, X) {
 #' learner for each point in the features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_treatment_outcome}{\code{IAI.predict_treatment_outcome}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_treatment_outcome}{\code{IAI.predict_treatment_outcome}}
 #'
 #' @param lnr The learner or grid to use for prediction.
 #' @param X The features of the data.
@@ -734,7 +839,7 @@ predict_treatment_outcome <- function(lnr, X) {
 #' Impute missing values in a dataframe using a fitted imputation model
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.transform}{\code{IAI.transform}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.transform}{\code{IAI.transform}}
 #'
 #' @param lnr The learner or grid to use for imputation
 #' @param X The features of the data.
@@ -751,12 +856,12 @@ transform <- function(lnr, X) {
 #' values in these features
 #'
 #' Similar to calling
-#' \href{https://docs.interpretable.ai/v3.0.0/IAI-R/reference/#iai::fit}{\code{fit}}
+#' \code{\link{fit.imputation_learner}}
 #' followed by
-#' \href{https://docs.interpretable.ai/v3.0.0/IAI-R/reference/#iai::transform}{\code{transform}}
+#' \code{\link{transform}}
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.fit_transform!}{\code{IAI.fit_transform!}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit_transform!}{\code{IAI.fit_transform!}}
 #'
 #' @param lnr The learner or grid to use for imputation
 #' @param X The features of the data.
@@ -774,7 +879,7 @@ fit_transform <- function(lnr, X, ...) {
 #' values in these features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.fit_transform_cv!}{\code{IAI.fit_transform_cv!}}
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit_transform_cv!}{\code{IAI.fit_transform_cv!}}
 #'
 #' @param grid The grid to use for imputation
 #' @param X The features of the data.
@@ -786,3 +891,90 @@ fit_transform <- function(lnr, X, ...) {
 fit_transform_cv <- function(grid, X, ...) {
   jl_func("IAI.fit_transform_cv_convert", grid, X, ...)
 }
+
+
+#' Output an object as an interactive browser visualization in HTML format
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.write_html-Tuple\%7BAny\%2C\%20AbstractVisualization\%7D}{\code{IAI.write_html}}
+#'
+#' @param filename Where to save the output.
+#' @param obj The object to output.
+#' @param ... Refer to the Julia documentation for available parameters.
+#'
+#' @examples \dontrun{iai::write_html(file.path(tempdir(), "out.html"), lnr)}
+#'
+#' @export
+write_html.abstract_visualization <- function(filename, obj, ...) {
+  write_html_common(filename, obj, ...)
+}
+#' Output an ROC curve as an interactive browser visualization in HTML format
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.write_html-Tuple\%7BAny\%2C\%20ROCCurve\%7D}{\code{IAI.write_html}}
+#'
+#' @param filename Where to save the output.
+#' @param obj The curve to output.
+#' @param ... Refer to the Julia documentation for available parameters.
+#'
+#' @examples \dontrun{iai::write_html(file.path(tempdir(), "roc.html"), lnr)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 1.1 or higher.
+#'
+#' @export
+write_html.roc_curve <- function(filename, obj, ...) {
+  requires_iai_version("1.1.0", "write_html", "with `roc_curve`")
+  write_html_common(filename, obj, ...)
+}
+
+
+#' Construct an interactive questionnaire from multiple specified learners
+#'
+#' Refer to the
+#' \href{https://docs.interpretable.ai/v3.1.0/IAI-R/julia/#R-Interactive-Visualizations-1}{documentation on advanced tree visualization}
+#' for more information.
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.MultiQuestionnaire-Tuple\%7BPair\%7D}{\code{IAI.MultiQuestionnaire}}
+#'
+#' @param obj The questions to visualize. Refer to the \href{https://docs.interpretable.ai/v3.1.0/IAITrees/visualization/#multivis-1}{Julia documentation on multi-learner visualizations} for more information.
+#' @param ... Additional arguments (unused)
+#'
+#' @examples
+#' \dontrun{
+#' iai::multi_questionnaire(list("Questionnaire for" = list(
+#'    "first learner" = lnr1,
+#'    "second learner" = lnr2
+#' )))
+#' }
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 1.1 or higher.
+#'
+#' @export
+multi_questionnaire.default <- function(obj, ...) {
+  requires_iai_version("1.1.0", "multi_questionnaire", "with `list`")
+  multi_questionnaire_common(obj, ...)
+}
+
+
+#' Construct an interactive tree questionnaire using multiple learners from the
+#' results of a grid search
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.MultiQuestionnaire-Tuple\%7BGridSearch\%7D}{\code{IAI.MultiQuestionnaire}}
+#'
+#' @param obj The grid to visualize
+#' @param ... Additional arguments (unused)
+#'
+#' @examples \dontrun{iai::multi_questionnaire(grid)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 2.0 or higher.
+#'
+#' @export
+multi_questionnaire.grid_search <- function(obj, ...) {
+  requires_iai_version("2.0.0", "multi_questionnaire", "with `grid_search`")
+  multi_questionnaire_common(obj, ...)
+}
