@@ -1,7 +1,7 @@
 #' Impute missing values using either a specified method or through validation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.impute}{\code{IAI.impute}}
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.impute}{\code{IAI.impute}}
 #'
 #' This function was deprecated in iai 1.7.0. This is for consistency with the
 #' IAI v3.0.0 Julia release.
@@ -21,7 +21,7 @@ impute <- function(X, ...) {
 #' Impute missing values using cross validation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.impute_cv}{\code{IAI.impute_cv}}
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.impute_cv}{\code{IAI.impute_cv}}
 #'
 #' This function was deprecated in iai 1.7.0. This is for consistency with the
 #' IAI v3.0.0 Julia release.
@@ -41,7 +41,7 @@ impute_cv <- function(X, ...) {
 #' Generic learner for imputing missing values
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.ImputationLearner}{\code{IAI.ImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.ImputationLearner}{\code{IAI.ImputationLearner}}
 #'
 #' @param method (optional) Specifies the imputation method to use.
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
@@ -58,7 +58,7 @@ imputation_learner <- function(method = "opt_knn", ...) {
 #' Learner for conducting optimal k-NN imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.OptKNNImputationLearner}{\code{IAI.OptKNNImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.OptKNNImputationLearner}{\code{IAI.OptKNNImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -74,7 +74,7 @@ opt_knn_imputation_learner <- function(...) {
 #' Learner for conducting optimal SVM imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.OptSVMImputationLearner}{\code{IAI.OptSVMImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.OptSVMImputationLearner}{\code{IAI.OptSVMImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -90,7 +90,7 @@ opt_svm_imputation_learner <- function(...) {
 #' Learner for conducting optimal tree-based imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.OptTreeImputationLearner}{\code{IAI.OptTreeImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.OptTreeImputationLearner}{\code{IAI.OptTreeImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -106,7 +106,7 @@ opt_tree_imputation_learner <- function(...) {
 #' Learner for conducting heuristic k-NN imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.SingleKNNImputationLearner}{\code{IAI.SingleKNNImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.SingleKNNImputationLearner}{\code{IAI.SingleKNNImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -122,7 +122,7 @@ single_knn_imputation_learner <- function(...) {
 #' Learner for conducting mean imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.MeanImputationLearner}{\code{IAI.MeanImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.MeanImputationLearner}{\code{IAI.MeanImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -138,7 +138,7 @@ mean_imputation_learner <- function(...) {
 #' Learner for conducting random imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.RandImputationLearner}{\code{IAI.RandImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.RandImputationLearner}{\code{IAI.RandImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -154,7 +154,7 @@ rand_imputation_learner <- function(...) {
 #' Learner for conducting zero-imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.ZeroImputationLearner}{\code{IAI.ZeroImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.ZeroImputationLearner}{\code{IAI.ZeroImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -175,7 +175,7 @@ zero_imputation_learner <- function(...) {
 #' indicator features to encode the missing pattern
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.fit_and_expand!}{\code{IAI.fit_and_expand!}}
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.fit_and_expand!}{\code{IAI.fit_and_expand!}}
 #'
 #' @param lnr The learner to use for imputation.
 #' @param X The dataframe in which to impute missing values.
@@ -189,7 +189,7 @@ zero_imputation_learner <- function(...) {
 #' @export
 fit_and_expand <- function(lnr, X, ...) {
   requires_iai_version("3.0.0", "fit_and_expand")
-  set_obj_class(jl_func("IAI.fit_and_expand_convert", lnr, X, ...))
+  jl_func("IAI.fit_and_expand_convert", lnr, X, ...)
 }
 
 
@@ -197,7 +197,7 @@ fit_and_expand <- function(lnr, X, ...) {
 #' indicator features to encode the missing pattern
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.transform_and_expand}{\code{IAI.transform_and_expand}}
+#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.transform_and_expand}{\code{IAI.transform_and_expand}}
 #'
 #' @param lnr The learner to use for imputation.
 #' @param X The dataframe in which to impute missing values.
@@ -211,5 +211,5 @@ fit_and_expand <- function(lnr, X, ...) {
 #' @export
 transform_and_expand <- function(lnr, X, ...) {
   requires_iai_version("3.0.0", "transform_and_expand")
-  set_obj_class(jl_func("IAI.transform_and_expand_convert", lnr, X, ...))
+  jl_func("IAI.transform_and_expand_convert", lnr, X, ...)
 }
