@@ -62,11 +62,82 @@ reward_estimator <- function(...) {
 }
 
 
+#' Calculate the scores for a categorical reward estimator on the given data
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.score-Tuple\%7BCategoricalRewardEstimator\%7D}{\code{IAI.score}}
+#'
+#' @param obj The learner or grid to evaluate.
+#' @param X The features of the data.
+#' @param ... Other parameters, including zero or more target vectors as
+#'            required by the problem type. Refer to the Julia
+#'            documentation for other available parameters.
+#'
+#' @examples \dontrun{iai::score(lnr, X, treatments, outcomes)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 2.1 or higher.
+#'
+#' @export
+score.categorical_reward_estimator <- function(obj, X, ...) {
+  requires_iai_version("2.1.0", "score", "with `categorical_reward_estimator`")
+  score_common(obj, X, ...)
+}
+
+
+#' Return counterfactual rewards estimated by a categorical reward estimator for
+#' each observation in the supplied data
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.predict-Tuple\%7BCategoricalRewardEstimator\%7D}{\code{IAI.predict}}
+#'
+#' @param obj The learner or grid to use for estimation
+#' @param X The features of the data.
+#' @param ... Additional arguments depending on the treatment and outcome types.
+#'            Refer to the Julia documentation for more information.
+#'
+#' @examples \dontrun{iai::predict(lnr, X, treatments, outcomes)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 2.0 or higher.
+#'
+#' @export
+predict.categorical_reward_estimator <- function(obj, X, ...) {
+  requires_iai_version("2.0.0", "predict",
+                       "with `categorical_reward_estimator`")
+  predict_common(obj, X, ...)
+}
+
+
+#' Return counterfactual rewards estimated by a categorical reward estimator for
+#' each observation in the supplied data and predictions
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.predict_reward-Tuple\%7BCategoricalRewardEstimator\%7D}{\code{IAI.predict_reward}}
+#'
+#' @param obj The learner or grid to use for estimation
+#' @param X The features of the data.
+#' @param ... Additional arguments depending on the treatment and outcome types.
+#'            Refer to the Julia documentation for more information.
+#'
+#' @examples \dontrun{iai::predict_reward(lnr, X, treatments, outcomes, predictions)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 3.0 or higher.
+#'
+#' @export
+predict_reward.categorical_reward_estimator <- function(obj, X, ...) {
+  requires_iai_version("3.0.0", "predict_reward",
+                       "with `categorical_reward_estimator`")
+  predict_reward_common(obj, X, ...)
+}
+
+
 #' Learner for conducting reward estimation with categorical treatments and
 #' classification outcomes
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.CategoricalClassificationRewardEstimator}{\code{IAI.CategoricalClassificationRewardEstimator}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.CategoricalClassificationRewardEstimator}{\code{IAI.CategoricalClassificationRewardEstimator}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -88,7 +159,7 @@ categorical_classification_reward_estimator <- function(...) {
 #' regression outcomes
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.CategoricalRegressionRewardEstimator}{\code{IAI.CategoricalRegressionRewardEstimator}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.CategoricalRegressionRewardEstimator}{\code{IAI.CategoricalRegressionRewardEstimator}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -110,7 +181,7 @@ categorical_regression_reward_estimator <- function(...) {
 #' survival outcomes
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.CategoricalSurvivalRewardEstimator}{\code{IAI.CategoricalSurvivalRewardEstimator}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.CategoricalSurvivalRewardEstimator}{\code{IAI.CategoricalSurvivalRewardEstimator}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -159,11 +230,81 @@ numeric_reward_estimator <- function(...) {
 }
 
 
+#' Calculate the scores for a numeric reward estimator on the given data
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.score-Tuple\%7BNumericRewardEstimator\%7D}{\code{IAI.score}}
+#'
+#' @param obj The learner or grid to evaluate.
+#' @param X The features of the data.
+#' @param ... Other parameters, including zero or more target vectors as
+#'            required by the problem type. Refer to the Julia
+#'            documentation for other available parameters.
+#'
+#' @examples \dontrun{iai::score(lnr, X, treatments, outcomes)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 2.1 or higher.
+#'
+#' @export
+score.numeric_reward_estimator <- function(obj, X, ...) {
+  requires_iai_version("2.1.0", "score", "with `numeric_reward_estimator`")
+  score_common(obj, X, ...)
+}
+
+
+#' Return counterfactual rewards estimated by a numeric reward estimator for
+#' each observation in the supplied data
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.predict-Tuple\%7BNumericRewardEstimator\%7D}{\code{IAI.predict}}
+#'
+#' @param obj The learner or grid to use for estimation
+#' @param X The features of the data.
+#' @param ... Additional arguments depending on the treatment and outcome types.
+#'            Refer to the Julia documentation for more information.
+#'
+#' @examples \dontrun{iai::predict(lnr, X, treatments, outcomes)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 2.1 or higher.
+#'
+#' @export
+predict.numeric_reward_estimator <- function(obj, X, ...) {
+  requires_iai_version("2.1.0", "predict", "with `numeric_reward_estimator`")
+  predict_common(obj, X, ...)
+}
+
+
+#' Return counterfactual rewards estimated by a numeric reward estimator for
+#' each observation in the supplied data and predictions
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.predict_reward-Tuple\%7BNumericRewardEstimator\%7D}{\code{IAI.predict_reward}}
+#'
+#' @param obj The learner or grid to use for estimation
+#' @param X The features of the data.
+#' @param ... Additional arguments depending on the treatment and outcome types.
+#'            Refer to the Julia documentation for more information.
+#'
+#' @examples \dontrun{iai::predict_reward(lnr, X, treatments, outcomes, predictions)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 3.0 or higher.
+#'
+#' @export
+predict_reward.numeric_reward_estimator <- function(obj, X, ...) {
+  requires_iai_version("3.0.0", "predict_reward",
+                       "with `numeric_reward_estimator`")
+  predict_reward_common(obj, X, ...)
+}
+
+
 #' Learner for conducting reward estimation with numeric treatments and
 #' classification outcomes
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.NumericClassificationRewardEstimator}{\code{IAI.NumericClassificationRewardEstimator}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.NumericClassificationRewardEstimator}{\code{IAI.NumericClassificationRewardEstimator}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -185,7 +326,7 @@ numeric_classification_reward_estimator <- function(...) {
 #' regression outcomes
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.NumericRegressionRewardEstimator}{\code{IAI.NumericRegressionRewardEstimator}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.NumericRegressionRewardEstimator}{\code{IAI.NumericRegressionRewardEstimator}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -206,7 +347,7 @@ numeric_regression_reward_estimator <- function(...) {
 #' outcomes
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.NumericSurvivalRewardEstimator}{\code{IAI.NumericSurvivalRewardEstimator}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.NumericSurvivalRewardEstimator}{\code{IAI.NumericSurvivalRewardEstimator}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -229,7 +370,7 @@ numeric_survival_reward_estimator <- function(...) {
 #' be randomly assigned.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.EqualPropensityEstimator}{\code{IAI.EqualPropensityEstimator}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.EqualPropensityEstimator}{\code{IAI.EqualPropensityEstimator}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -246,56 +387,55 @@ equal_propensity_estimator <- function(...) {
 }
 
 
-#' Fit a reward estimation model on features, treatments and outcomes and
-#' return predicted counterfactual rewards for each observation, as well as the
-#' score of the internal estimators.
-#'
-#' For categorical treatments, returns the estimated reward under each
-#' treatment observed in the data. For numeric treatments, returns the
-#' estimated reward under each treatment candidate.
+#' Fit a categorical reward estimator on features, treatments and
+#' outcomes and return predicted counterfactual rewards for each observation,
+#' under each treatment observed in the data, as well as the scores of the
+#' internal estimators.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.fit_predict!}{\code{IAI.fit_predict!}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.fit_predict\%21-Tuple\%7BCategoricalRewardEstimator\%7D}{\code{IAI.fit_predict!}}
 #'
-#' @param lnr The learner or grid to use for estimation
+#' @param obj The learner or grid to use for estimation
 #' @param X The features of the data.
 #' @param treatments The treatment applied to each point in the data.
 #' @param ... Additional arguments depending on the treatment and outcome types.
 #'            Refer to the Julia documentation for more information.
 #'
-#' @examples \dontrun{iai::fit_predict(lnr, X, treatments, outcomes)}
+#' @examples \dontrun{iai::fit_predict(obj, X, treatments, outcomes)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 2.0 or higher.
 #'
 #' @export
-fit_predict <- function(lnr, X, treatments, ...) {
-  out <- jl_func("IAI.fit_predict_convert", lnr, X, treatments, ...)
-  if (!iai_version_less_than("3.0.0")) {
-    names(out) <- c("predictions", "score")
-  } else if (!iai_version_less_than("2.1.0")) {
-    names(out) <- c("rewards", "score")
-  }
-  out
+fit_predict.categorical_reward_estimator <- function(obj, X, treatments, ...) {
+  requires_iai_version("2.0.0", "fit_predict",
+                       "with `categorical_reward_estimator`")
+  fit_predict_common(obj, X, treatments, ...)
 }
-
-
-#' Return counterfactual rewards estimated using learner parameters for each
-#' observation in the supplied data and predictions
+#' Fit a numeric reward estimator on features, treatments and
+#' outcomes and return predicted counterfactual rewards for each observation,
+#' under each treatment candidate, as well as the scores of the internal
+#' estimators.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.predict_reward}{\code{IAI.predict_reward}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.fit_predict\%21-Tuple\%7BNumericRewardEstimator\%7D}{\code{IAI.fit_predict!}}
 #'
-#' @param lnr The learner or grid to use for estimation
+#' @param obj The learner or grid to use for estimation
+#' @param X The features of the data.
+#' @param treatments The treatment applied to each point in the data.
 #' @param ... Additional arguments depending on the treatment and outcome types.
 #'            Refer to the Julia documentation for more information.
 #'
-#' @examples \dontrun{iai::predict_reward(lnr, treatments, outcomes, predictions)}
+#' @examples \dontrun{iai::fit_predict(obj, X, treatments, outcomes)}
 #'
 #' @section IAI Compatibility:
-#' Requires IAI version 3.0 or higher.
+#' Requires IAI version 2.1 or higher.
 #'
 #' @export
-predict_reward <- function(lnr, ...) {
-  requires_iai_version("3.0.0", "predict_reward")
-  jl_func("IAI.predict_reward_convert", lnr, ...)
+fit_predict.numeric_reward_estimator <- function(obj, X, treatments, ...) {
+  requires_iai_version("2.1.0", "fit_predict",
+                       "with `numeric_reward_estimator`")
+  fit_predict_common(obj, X, treatments, ...)
 }
 
 
@@ -303,7 +443,7 @@ predict_reward <- function(lnr, ...) {
 #' propensity/outcome estimation problems in a fitted learner.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.get_estimation_densities}{\code{IAI.get_estimation_densities}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.get_estimation_densities}{\code{IAI.get_estimation_densities}}
 #'
 #' @param lnr The learner from which to extract densities
 #' @param ... Refer to the Julia documentation for other parameters
@@ -324,7 +464,7 @@ get_estimation_densities <- function(lnr, ...) {
 #' bandwidths and return the final tuned values.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.tune_reward_kernel_bandwidth}{\code{IAI.tune_reward_kernel_bandwidth}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.tune_reward_kernel_bandwidth}{\code{IAI.tune_reward_kernel_bandwidth}}
 #'
 #' @param lnr The learner to use for tuning the bandwidth
 #' @param ... Refer to the Julia documentation for other parameters
@@ -346,7 +486,7 @@ tune_reward_kernel_bandwidth <- function(lnr, ...) {
 #' train the learner.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.set_reward_kernel_bandwidth!}{\code{IAI.set_reward_kernel_bandwidth!}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.set_reward_kernel_bandwidth!}{\code{IAI.set_reward_kernel_bandwidth!}}
 #'
 #' @param lnr The learner to modify
 #' @param ... Refer to the Julia documentation for available parameters.
@@ -368,7 +508,7 @@ set_reward_kernel_bandwidth <- function(lnr, ...) {
 #' or `predict`
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.all_treatment_combinations}{\code{IAI.all_treatment_combinations}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.all_treatment_combinations}{\code{IAI.all_treatment_combinations}}
 #'
 #' @param ... A vector of possible options for each treatment
 #'
@@ -384,7 +524,7 @@ all_treatment_combinations <- function(...) {
 #' Convert `treatments` from symbol/string format into numeric values.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.convert_treatments_to_numeric}{\code{IAI.convert_treatments_to_numeric}}
+#' \href{https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.convert_treatments_to_numeric}{\code{IAI.convert_treatments_to_numeric}}
 #'
 #' @param treatments The treatments to convert
 #'
